import datetime
import ephem
import sys

#cmd line tool to find full moons for given month/year AND phase percentage on any day
#ironfelix717 @ access-programmers.co.uk
#modified example from https://stackoverflow.com/questions/2526815/moon-lunar-phase-algorithm

def get_phase_on_day(year,month,day):
  """Returns a floating-point number from 0-1. where 0=new, 0.5=full, 1=new"""
  #Ephem stores its date numbers as floating points, which the following uses
  #to conveniently extract the percent time between one new moon and the next
  #This corresponds (somewhat roughly) to the phase of the moon.

  #Use Year, Month, Day as arguments
  date=ephem.Date(datetime.date(year,month,day))

  nnm = ephem.next_new_moon    (date)
  pnm = ephem.previous_new_moon(date)

  lunation=(date-pnm)/(nnm-pnm)

  #Note that there is a ephem.Moon().phase() command, but this returns the
  #percentage of the moon which is illuminated. This is not really what we want.

  return lunation

def get_full_moon(month, year):
    moons = ""

    date=ephem.Date(datetime.date(year,month,1))
    while date.datetime().year==year and date.datetime().month==month:
      date=ephem.next_full_moon(date)
      #more than 1 full moon may occur in a month (march 2018, jan 2018)
      if date.datetime().month==month:
        moons = moons + "," + str(date)
    return moons[1:] #remove comma

def Run():
  year = 0
  month = 0
  day = 0
  args = []
  return_value = ""
  try:
    args=sys.argv
    
    if len(args) == 3 + 1: #remember sysargs[0] is always prog name
      #get phase of moon by date
      #order is:  month,day,year,
      month = int(args[1])
      day = int(args[2])
      year = int(args[3])
      return_value= round(get_phase_on_day(year,month,day),4)
    elif len(args)== 2 +1:
      #get full moon by month and year
      #may return more than one full moon!
      month = int(args[1])
      year = int(args[2])
      return_value = get_full_moon(month,year)
    else:
        return_value= "ERROR: Expected 2 or 3 arguments. Provided=" + str(len(args)-1)
  except Exception as e:
    return_value = "ERROR: internal exception was raised: \n" + "       " + str(e) +" on Line {}".format(sys.exc_info()[-1].tb_lineno)
  return return_value

print(Run())
